@@ -14,10 +14,13 @@ from je_auto_control.wrapper.platform_wrapper import keyboard_check
 from je_auto_control.wrapper.platform_wrapper import keys_table
 
 
-def press_key(keycode: [int, str], is_shift: bool = False, **kwargs):
+def press_key(keycode: [int, str], is_shift: bool = False):
     """
+    use to press a key still press to use release key
+    or use critical exit
+    return keycode
     :param keycode which keycode we want to press
-    :param is_shift shift is press?
+    :param is_shift press shift True or False
     """
     if type(keycode) is not int:
         try:
@@ -36,10 +39,11 @@ def press_key(keycode: [int, str], is_shift: bool = False, **kwargs):
         raise AutoControlKeyboardException(repr(error))
 
 
-def release_key(keycode: [int, str], is_shift: bool = False, **kwargs):
+def release_key(keycode: [int, str], is_shift: bool = False):
     """
+    use to release pressed key return keycode
     :param keycode which keycode we want to release
-    :param is_shift shift is press?
+    :param is_shift press shift True or False
     """
     if type(keycode) is not int:
         try:
@@ -58,10 +62,11 @@ def release_key(keycode: [int, str], is_shift: bool = False, **kwargs):
         raise AutoControlKeyboardException(repr(error))
 
 
-def type_key(keycode: [int, str], is_shift: bool = False, **kwargs):
+def type_key(keycode: [int, str], is_shift: bool = False):
     """
+    press and release key return keycode
     :param keycode which keycode we want to type
-    :param is_shift shift is press?
+    :param is_shift press shift True or False
     """
     try:
         press_key(keycode, is_shift)
@@ -73,9 +78,10 @@ def type_key(keycode: [int, str], is_shift: bool = False, **kwargs):
         raise AutoControlKeyboardException(repr(error))
 
 
-def check_key_is_press(keycode: [int, str], **kwargs):
+def check_key_is_press(keycode: [int, str]):
     """
-    :param keycode check key press?
+    use to check key is press return True or False
+    :param keycode check key is press or not
     """
     if type(keycode) is int:
         get_key_code = keycode
@@ -84,10 +90,12 @@ def check_key_is_press(keycode: [int, str], **kwargs):
     return keyboard_check.check_key_is_press(keycode=get_key_code)
 
 
-def write(write_string: str, is_shift: bool = False, **kwargs):
+def write(write_string: str, is_shift: bool = False):
     """
+    use to press and release whole we get this function str
+    return all press and release str
     :param write_string while string not on write_string+1 type_key(string)
-    :param is_shift shift is press?
+    :param is_shift press shift True or False
     """
     try:
         record_write_string = ""
@@ -105,10 +113,13 @@ def write(write_string: str, is_shift: bool = False, **kwargs):
         raise AutoControlKeyboardException(keyboard_write)
 
 
-def hotkey(key_code_list: list, is_shift: bool = False, **kwargs):
+def hotkey(key_code_list: list, is_shift: bool = False):
     """
+    use to press and release all key on key_code_list
+    then reverse list press and release again
+    return [press_str_list, release_str_list]
     :param key_code_list press and release all key on list and reverse
-    :param is_shift shift is press?
+    :param is_shift press shift True or False
     """
     try:
         record_hotkey_press_string = ""
