@@ -8,12 +8,18 @@ from je_auto_control.wrapper.platform_wrapper import recorder
 
 
 def record():
+    """
+    start record keyboard and mouse event until stop_record
+    """
     if sys.platform == "darwin":
         raise AutoControlException(macos_record_error)
     return recorder.record()
 
 
 def stop_record():
+    """
+    stop current record
+    """
     if sys.platform == "darwin":
         raise AutoControlException(macos_record_error)
     action_queue = recorder.stop_record()
@@ -28,12 +34,3 @@ def stop_record():
             new_list.append([action[0], dict(zip(["mouse_keycode", "x", "y"], [action[0], action[1], action[2]]))])
     return new_list
 
-
-if __name__ == "__main__":
-    record()
-    from time import sleep
-    sleep(5)
-    record_result = stop_record()
-    print(record_result)
-    execute_action(record_result)
-    sleep(2)
