@@ -18,8 +18,9 @@ def size():
         raise AutoControlScreenException(screen_get_size)
 
 
-def screenshot(file_path: str = None, region: list = None, **kwargs):
+def screenshot(file_path: str = None, region: list = None):
     """
+    use to capture current screen image
     :param file_path screenshot file save path
     :param region screenshot region
     """
